#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Script to replace extra slashes in incoming file.  Designed for LDAP property files.

Usage::

    python replace_extra_slash.py Custom_LDAPSecurity.properties
'''
import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
# pylint: disable=line-too-long
sys.path.append(next(p for p in ['..', '../..'] if os.path.exists(p + '/qdlib') and (p + '/qdlib') not in sys.path))
# pylint: enable=line-too-long

from qdlib import qd


def replace(working_file, before, after):
    ''' Given a file and 'before' and 'after' strings, replace all instances of the 'before'
    strings in the file.

    :param working_file: file that replacements will happen in; changes are made to that file
    :param before: string to be replaced
    :param after: string that replaces the original string
    '''

    replacement_list = [(before, after)]
    qd.sed_in_place(working_file, replacement_list)


def main(argv):
    '''Main function; see module documentation.'''

    # check inputs; need a file to work on
    qd.process_inputs(argv[:2], 'file to update', output=False)

    file_ = argv[1]
    qd.echo_info('Replace slashes in file [%s]' % file_)

    # Check that the file really exists
    if not os.path.exists(file_):
        raise Exception('File [%s] does not exist.' % file_)

    # To replace the slashes properly, we need to perform three separate replacements

    # Replacement 1: Save special \
    before = '\\\\\\\\\\\\'
    after = '\\\\_KEEP_THIS_BACK_SPLASH_'
    qd.echo_debug('Replacing [%s] with [%s]' % (before, after))
    replace(file_, before, after)

    # Replacement 2: Replace other \
    before = '\\\\'
    after = ''
    qd.echo_debug('Replacing [%s] with [%s]' % (before, after))
    replace(file_, before, after)

    # Replacement 3: Replace saved \
    before = '_KEEP_THIS_BACK_SPLASH_'
    after = '\\\\'
    qd.echo_debug('Replacing [%s] with [%s]' % (before, after))
    replace(file_, before, after)

    # At this point, the file has been modified in place.


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main(sys.argv)
    exit(0)
