#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2016, 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Append DB2Parameter.properties when the topology uses a DB server.
'''

import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
# pylint: disable=line-too-long
sys.path.append(next(p for p in ['..', '../..'] if os.path.exists(p + '/qdlib') and (p + '/qdlib') not in sys.path))
# pylint: enable=line-too-long

from qdlib import qd, qd_props


def main():
    '''
    Main function; see module documentation.
    '''

    # load host info
    env_props = qd_props.get_default_env_props()

    # if DB2 or ORACLE
    if env_props.get_values('DB_VENDOR') == "db2":
        qd.echo_info("Appending db2Parameter.properties to env.properties...")
        if qd.is_linux():
            qd.call('cat db2Parameter.properties >> %s'
                    % os.path.abspath(env_props.filename), shell=True)
        else:
            qd.call('type db2Parameter.properties >> %s'
                    % os.path.abspath(env_props.filename), shell=True)
    elif env_props.get_values('DB_VENDOR') == "oracle":
        qd.echo_info("Appending oracleParameter.properties to env.properties...")
        if qd.is_linux():
            qd.call('cat oracleParameter.properties >> %s'
                    % os.path.abspath(env_props.filename), shell=True)
        else:
            qd.call('type oracleParameter.properties >> %s'
                    % os.path.abspath(env_props.filename), shell=True)
    else:
        qd.echo_info("Skipped to append (db2)(oracle)Parameter.properties to env.properties"
                     " as DB is [%s]" % env_props.get_values('DB_VENDOR'))


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main()
    exit(0)
