#!/bin/sh
#********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
#********************************************************************************
#############
## FUNCTIONS 
#############

checkOS()
{
	####################################
	# may need to check OS 
	bRH6flag=FALSE
	bRH7flag=FALSE
	
	RHversion=`cat /etc/redhat-release`
	echo "Current Red Hat Release $RHversion"
	
	case "$RHversion" in
        *Maipo*) echo "OS is Redhat 7"; bRH7flag=TRUE;;
        *Santiago*) echo "OS is Redhat 6"; bRH6flag=TRUE;;
        *)        echo "OS is not a supported version"; exit 1;;
esac
	
}

########################################
# Main
########################################

scriptName=$0
if [ $# == 0 ]; then
	echo "ERROR: script "${scriptName}" has no input parameters"
	echo "Please pass in env.properites file parent folder"
	exit 1
fi
env_prop_root=$1
echo "INFO: env.properties parent folder [$env_prop_root]"
envProp=${env_prop_root}/env.properties
. $envProp

# xvfb only required on RM and DM servers
echo "if required [RM & DM] ensure XVFB is running"
echo "localTagList ["${localTags}"]"
tagList=${localTags//,/ }
for tag in $tagList
do
  # determine which repReqs to check
  if [[ $tag == "RM" ]] || [[ $tag == "DM" ]]; then
	  # Xvfb is a system requirement
	  echo "---Require Xvfb on port :3---"
	  if ps -ef | grep -v "grep" | grep "Xvfb.*:3 "
	  then
	    echo "Xvfb [:3] already running"
	  else
	    echo "starting Xvfb [:3]"
	    Xvfb :3 -screen 0 800x600x24 >&- 2>&- & 
	    sleep 10
	    
	    if ps -ef | grep -v "grep" | grep "Xvfb.*:3 "
	    then
	      echo "Xvfb [:3] running"
	    else
	      echo "ERROR: Xvfb [:3] not running!"
	      exit 1
	    fi
	   fi
  
	  echo "---Setting DISPLAY---"
	  DISPLAY=:3.0
	  export DISPLAY
  
  
	  # setting up automatically start up script for Xvfb
	  checkOS
	  if [ "TRUE" == $bRH6flag ]; then
	    echo "*** Setup ${AUTO_PREP}/ibm-xvfb init.d"
	    cp ${AUTO_PREP}/ibm-xvfb /etc/init.d
	    chmod o+x /etc/init.d/ibm-xvfb
	    chkconfig --add ibm-xvfb
	    echo "checking start up scripts"
	    ls -l /etc/init.d/ibm-xvfb
	    chkconfig --list ibm-xvfb
	    if [ $? -gt 0 ]; then
	       echo "ERROR: failed to add ibm-xvfb as service"
	       exit 1
	    fi
	  else
	    echo "*** Setup ${AUTO_PREP}/ibm-xvfb systemd"
	    if [ ! -d /usr/lib/systemd/scripts/ ];then
	      mkdir /usr/lib/systemd/scripts/
	    fi
	    cp ${AUTO_PREP}/ibm-xvfb /usr/lib/systemd/scripts/
	    chmod o+x /usr/lib/systemd/scripts/ibm-xvfb
	    cp ${AUTO_PREP}/ibm-xvfb.service /usr/lib/systemd/system/
	    systemctl enable ibm-xvfb.service
	    echo "checking start up scripts"
	    ls -l /usr/lib/systemd/scripts/ibm-xvfb
	    ls -la /etc/systemd/system/multi-user.target.wants | grep ibm-xvfb.service
	    if [ $? -gt 0 ]; then
	       echo "ERROR: failed to add ibm-xvfb as service"
	       exit 1
	    fi
	  fi
	fi
 done
  
