#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Setup Single Sign On between WebSphere application server nodes.  See :func:`main` function.
'''
import os
import sys

# find qdlib from parent paths and add the first one to the Python search path
# pylint: disable=line-too-long
sys.path.append(next(p for p in ['..', '../..', '../../..'] if os.path.exists(p + '/qdlib') and (p + '/qdlib') not in sys.path))
# pylint: enable=line-too-long

from qdlib import qd, qd_props, install_util


def main(argv):
    '''
    Main function to set up Single Sign on between WebSphere application server nodes.

    :param argv [export/import]: determines if enable_sso.jy exports or imports the JTS LTPA key
    '''
    if len(argv) == 1:
        option = argv[0]
    else:
        qd.exit_with_err_msg("Missing option [ import, export ] ")
    working_dir = os.getcwdu()
    env_props = qd_props.get_default_env_props()
    if option == 'import':
        if qd.is_windows():
            cmd = ['net', 'share', qd_props.DEFAULT_REL_TMP_DIR, '/Y', '/DELETE']
            qd.check_call(cmd)

    if 'JTS' in env_props.get_values('localTags') and option == 'import':
        qd.echo_info("This is a JTS node, do not need import the key file ")
        qd.exit_(0)
    user_props = qd_props.get_user_props(env_props)
    ihs_password = user_props.get_values(qd_props.PN_IHS_KEYSTORE_PASSWORD)
    ihs_password = qd.decode_base64(ihs_password)
    os_user_name, os_user_password = qd_props.get_os_users_creds(user_props)
    # the password file include the decrypted ihs keystore password
    password_file = qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                                 qd_props.DEFAULT_REL_TMP_DIR, 'keypwd.txt')
    # create temporary qd_tmp directory under QD_Root
    qd.check_and_create_folder(qd.dirname(password_file))
    qd.chmod_777(qd.dirname(password_file), 'o+w')
    qd.create_file(password_file)
    qd.check_file_exists(password_file)
    qd.QDEnv.set_value_to_prop_file(password_file, 'keypwd', ihs_password)

    # call enable_sso.jy script to export/import
    cmd = [qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                        qd_props.DEFAULT_REL_WAS_PROFILE, 'bin',
                        qd_props.DEFAULT_WSADMIN_EXE), '-lang',
           'jython', '-f', qd.path_join(working_dir, 'enable_sso.jy'), option, password_file]
    install_util.su_call_if_necessary('--', (os_user_name, os_user_password),
                                      cmd, call_method=qd.check_call)
    qd.delete_file_if_exists(password_file)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main(sys.argv[1:])
    exit(0)
