#!/usr/bin/python
# ********************************************************************************
# Licensed Materials - Property of IBM
# IBM Quick Deployer
# (c) Copyright IBM Corporation 2017. All Rights Reserved.
#
# U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#
# ********************************************************************************
'''
Start, stop or restart WebSphere application server.  See :func:`main` function.
'''
import os
import sys
import time

# find qdlib from parent paths and add the first one to the Python search path
# pylint: disable=line-too-long
sys.path.append(next(p for p in ['..', '../..', '../../..'] if os.path.exists(p + '/qdlib') and (p + '/qdlib') not in sys.path))
# pylint: enable=line-too-long

from qdlib import qd, qd_props, install_util


def main(argv):
    '''
    Start, stop or restart websphere application server.

    :param argv: expect a single argument passes in the program,
           the option string should be "start", "stop", "restart"
    '''
    if len(argv) == 1:
        option = argv[0]
    else:
        qd.echo_error("Passed in number of arguments [%s]" % len(argv))
        qd.exit_with_err_msg("Missing start up option [ start, stop, restart ], ")

    if option == "start":
        qd.echo_info("Starting WebSphere Application server")
        exe_name = qd.os_switch('startServer.sh', 'startServer.bat')
    elif option == "stop":
        qd.echo_info("Stopping WebSphere Application server")
        exe_name = qd.os_switch('stopServer.sh', 'stopServer.bat')
    elif option == "restart":
        qd.echo_info("Restarting WebSphere Application server")
        exe_name = qd.os_switch('stopServer.sh', 'stopServer.bat')
        exe_start_name = qd.os_switch('startServer.sh', 'startServer.bat')
    else:
        qd.exit_with_err_msg("Unsupport WAS option [ %s ]" % option)

    env_props = qd_props.get_default_env_props()
    user_props = qd_props.get_user_props(env_props)
    os_user_name, os_user_password = qd_props.get_os_users_creds(user_props)

    # Start/Stop WebSphere application server
    cmd = [qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                        qd_props.DEFAULT_REL_WAS_PROFILE, 'bin',
                        exe_name), 'server1']
    install_util.su_call_if_necessary('--', (os_user_name, os_user_password),
                                      cmd, call_method=qd.check_call)
    if option == "restart":
        cmd = [qd.path_join(env_props.get_values(qd_props.PN_QD_ROOT),
                            qd_props.DEFAULT_REL_WAS_PROFILE, 'bin',
                            exe_start_name), 'server1']
        time.sleep(5)
        install_util.su_call_if_necessary('--', (os_user_name, os_user_password),
                                          cmd, call_method=qd.check_call)


if __name__ == '__main__':
    import logging
    logging.basicConfig(level=qd.LOG_DEFAULT_LEVEL, format=qd.LOG_DEFAULT_FORMAT,
                        datefmt=qd.LOG_DEFAULT_DATEFMT)
    main(sys.argv[1:])
    exit(0)
